w folderze /home/tom/github/wronai/markpact znajduje się działający projekt, biblitoeka i shell app dla generowania działającyhc usług z wykorzystaniem LLM oraz na bazie pliku markdown z kodem, ktory jest uruchamiany w sandbox , w pliku /home/tom/github/wronai/markpact/project.functions.toon
jest cała strukutra kodu, 
stwórz paczke python o nazwie pactown w aktualnym folderze ./ makefile i dokumentacją, który będzie odpiwedzialny za wykorzystanie markpact do zbudowania na bazie wielu sandboxow z wykorzystanie markpact zdecentralizowanych ekosystemów usług, artefaktów 
chodzi o możliwość łączenia wielu oddzielnych projektów z wykorzystaniem markpact w jeden system w którym kazdy z tych projektów w markdown był częścia całego systemu podobnie jak to się dzieje w zaleznosciach, stworz rowniez lokalny rejestr markpact jako usluge z api oraz jako lokalny klietn do tego rejestru, dzieki czemu mozliwe bedzie wykorzystanie roznych jezykow i roznych frameworkow w jednym ekosystemie, niezaleznie od technologii
Stworz specyfikacje całego systemu i problematyke, aby dziaały wszystkie uslugi razem, np osobno readme dla strony www, osobny dla bazy danych, osobny dla cli shell, podobnie jak te 3 moduły, ale by działały razem w ramach jednego systemu, stworz wiecej przykladow i polacz je razem, zkonfiguracją w pliku saas.pactown.yaml na bazie nowych przykładów i korzystając z już istniejących w  /home/tom/github/wronai/markpact/examples/*/README.md